import shutil
import sys

from .plot_theme import set_vscode_theme
from .plot_theme import vscode_theme
from .progress import pqdm, prange
# CPU monitoring
from .cpu_monitor import (
    CPUMonitor,
    monitor,
    CPUMonitorMagics,
    detect_compute_nodes,
    get_cached_nodes,
)
from .slurm_magic import SlurmMagic
from .utils import truncate_colormap, Left

try:
    from IPython import get_ipython
    ipython = get_ipython()
    if ipython is not None and CPUMonitorMagics is not None:
        ipython.register_magics(CPUMonitorMagics)
    if ipython is not None and SlurmMagic is not None:
        ipython.register_magics(SlurmMagic)
except (ImportError, NameError):
    print("IPython not available, skipping magic registration.", file=sys.stderr)
    # Not in IPython environment or magic not available
    pass


import matplotlib.pyplot as plt
import matplotlib.colors as colors
import numpy as np
from IPython.display import display

def truncate_colormap(cmap, minval=0.0, maxval=1.0, n=100):
    if isinstance(cmap, str):
        cmap = plt.get_cmap(cmap)
    new_cmap = colors.LinearSegmentedColormap.from_list(
        'trunc({n},{a:.2f},{b:.2f})'.format(n=cmap.name, a=minval, b=maxval),
        cmap(np.linspace(minval, maxval, n)))
    return new_cmap

class Left:
    def __rlshift__(self, df):
        "Left align columns of data frame: df << left()"
        left_aligned_df = df.style.set_properties(**{'text-align': 'left'})
        left_aligned_df = left_aligned_df.set_table_styles(
        [dict(selector = 'th', props=[('text-align', 'left')])])
        display(left_aligned_df)



import unittest

from vscodenb.modulename import functionname

class TestModulename(unittest.TestCase):

    def test_functionname(self):
        self.assertEqual(
            functionname(
                1, 1
                ),
                2
            )
